@@ -8,17 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-ecr-deployment",
-    "0.0.85",
-    __name__[0:-6],
-    "cdk-ecr-deployment@0.0.85.jsii.tgz",
+    "cdk-ecr-deployment", "2.1.0", __name__[0:-6], "cdk-ecr-deployment@2.1.0.jsii.tgz"
 )
 
 __all__ = [
